<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Blog Center
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
	<?php wp_body_open(); ?>
	<div id="page" class="site">
		<a class="skip-link screen-reader-text" href="#primary-content"><?php esc_html_e( 'Skip to content', 'blog-center' ); ?></a>

		<div id="loader">
			<div class="loader-container">
				<div id="preloader">
					<div class="pre-loader-7"></div>
				</div>
			</div>
		</div><!-- #loader -->

		<?php require get_template_directory() . '/inc/frontpage-sections/breaking-news.php'; ?>
		<header id="masthead" class="site-header">
			<?php $advertisement_image = get_theme_mod( 'blog_center_advertisement_image' ); ?>
			<div class="adore-header-title <?php echo esc_attr( $advertisement_image ? 'has-image' : 'no-image' ); ?>">
				<div class="theme-wrapper">
					<div class="adore-header-title-wrapper">
						<div class="site-branding">
							<?php
							$site_identity_options = get_theme_mod( 'blog_center_site_identity_extra_options', 'show-all' );

							if ( has_custom_logo() && in_array( $site_identity_options, array( 'show-all', 'logo-title', 'logo-tagline' ) ) ) {
								?>
								<div class="site-logo">
									<?php the_custom_logo(); ?>
								</div>
								<?php
							}

							if ( in_array( $site_identity_options, array( 'show-all', 'title-only', 'logo-title', 'tagline-only', 'logo-tagline' ) ) ) {

								if ( get_theme_mod( 'blog_center_header_text_display', true ) === true ) {
									?>

									<div class="site-identity">
										<?php
										if ( in_array( $site_identity_options, array( 'show-all', 'title-only', 'logo-title' ) ) ) {
											if ( is_front_page() && is_home() ) :
												?>
											<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
												<?php
										else :
											?>
											<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
											<?php
										endif;

										}

										if ( in_array( $site_identity_options, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {

											$blog_center_description = get_bloginfo( 'description', 'display' );
											if ( $blog_center_description || is_customize_preview() ) :
												?>
											<p class="site-description"><?php echo $blog_center_description; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></p>
												<?php
											endif;
										}
										?>
								</div>

									<?php
								}
							}
							?>
					</div><!-- .site-branding -->

					<?php
					$ads_image         = get_theme_mod( 'blog_center_advertisement_image', '' );
					$advertisement_url = get_theme_mod( 'blog_center_advertisement_url', '#' );
					if ( ! empty( $ads_image ) ) {
						?>
						<div class="adore-adver">
							<div class="adore-adver-outer">
								<a href="<?php echo esc_url( $advertisement_url ); ?>">
									<img src="<?php echo esc_url( $ads_image ); ?>" alt="<?php esc_attr_e( 'Advertisment Image', 'blog-center' ); ?>">
								</a>
							</div>
						</div>
					<?php } ?>
				</div>
			</div>
		</div>
		<div class="header-outer-wrapper">
			<div class="adore-header">
				<div class="theme-wrapper">
					<div class="header-wrapper">
						<div class="header-nav-search">
							<div class="header-navigation">
								<nav id="site-navigation" class="main-navigation">
									<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
										<span></span>
										<span></span>
										<span></span>
									</button>
									<?php

									if ( has_nav_menu( 'primary' ) ) {

										wp_nav_menu(
											array(
												'theme_location' => 'primary',
												'menu_id' => 'primary-menu',
											)
										);

									}

									?>
								</nav><!-- #site-navigation -->
							</div>
							<div class="header-end">
								<div class="social-icons">
									<?php
									if ( has_nav_menu( 'social' ) ) {
										wp_nav_menu(
											array(
												'menu_class'  => 'menu social-links',
												'link_before' => '<span class="screen-reader-text">',
												'link_after'  => '</span>',
												'theme_location' => 'social',
											)
										);
									}
									?>
								</div>
								<div class="navigation-search">
									<div class="navigation-search-wrap">
										<a href="#" title="Search" class="navigation-search-icon">
											<i class="fa fa-search"></i>
										</a>
										<div class="navigation-search-form">
											<?php get_search_form(); ?>
										</div>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	</header><!-- #masthead -->

	<div id="primary-content" class="primary-site-content">

		<?php
		if ( ! is_front_page() || is_home() ) {

			if ( is_front_page() ) {

				require get_template_directory() . '/inc/frontpage-sections/posts-carousel.php';

			}

			?>

			<div id="content" class="site-content theme-wrapper">
				<div class="theme-wrap">

				<?php } ?>
