<?php
/**
 * Adore Themes Customizer
 *
 * @package Blog Center
 *
 * Breaking News Section
 */

$wp_customize->add_section(
	'blog_center_breaking_news_section',
	array(
		'title' => esc_html__( 'Flash News Section', 'blog-center' ),
		'panel' => 'blog_center_frontpage_panel',
	)
);

// Breaking News section enable settings.
$wp_customize->add_setting(
	'blog_center_breaking_news_section_enable',
	array(
		'default'           => false,
		'sanitize_callback' => 'blog_center_sanitize_checkbox',
	)
);

$wp_customize->add_control(
	new Blog_Center_Toggle_Checkbox_Custom_control(
		$wp_customize,
		'blog_center_breaking_news_section_enable',
		array(
			'label'    => esc_html__( 'Enable Flash News Section', 'blog-center' ),
			'type'     => 'checkbox',
			'settings' => 'blog_center_breaking_news_section_enable',
			'section'  => 'blog_center_breaking_news_section',
		)
	)
);

// Breaking News title settings.
$wp_customize->add_setting(
	'blog_center_breaking_news_title',
	array(
		'default'           => __( 'Flash News', 'blog-center' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'blog_center_breaking_news_title',
	array(
		'label'           => esc_html__( 'Title', 'blog-center' ),
		'section'         => 'blog_center_breaking_news_section',
		'active_callback' => 'blog_center_if_breaking_news_enabled',
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'blog_center_breaking_news_title',
		array(
			'selector'            => '.news-ticker-section .theme-wrapper',
			'settings'            => 'blog_center_breaking_news_title',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'blog_center_breaking_news_title_text_partial',
		)
	);
}

// breaking_news content type settings.
$wp_customize->add_setting(
	'blog_center_breaking_news_content_type',
	array(
		'default'           => 'post',
		'sanitize_callback' => 'blog_center_sanitize_select',
	)
);

$wp_customize->add_control(
	'blog_center_breaking_news_content_type',
	array(
		'label'           => esc_html__( 'Content type:', 'blog-center' ),
		'description'     => esc_html__( 'Choose where you want to render the content from.', 'blog-center' ),
		'section'         => 'blog_center_breaking_news_section',
		'type'            => 'select',
		'active_callback' => 'blog_center_if_breaking_news_enabled',
		'choices'         => array(
			'post'     => esc_html__( 'Post', 'blog-center' ),
			'category' => esc_html__( 'Category', 'blog-center' ),
		),
	)
);

for ( $i = 1; $i <= 5; $i++ ) {
	// breaking_news post setting.
	$wp_customize->add_setting(
		'blog_center_breaking_news_post_' . $i,
		array(
			'sanitize_callback' => 'blog_center_sanitize_dropdown_pages',
		)
	);

	$wp_customize->add_control(
		'blog_center_breaking_news_post_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Post %d', 'blog-center' ), $i ),
			'section'         => 'blog_center_breaking_news_section',
			'type'            => 'select',
			'choices'         => blog_center_get_post_choices(),
			'active_callback' => 'blog_center_breaking_news_section_content_type_post_enabled',
		)
	);

}

// breaking_news category setting.
$wp_customize->add_setting(
	'blog_center_breaking_news_category',
	array(
		'sanitize_callback' => 'blog_center_sanitize_select',
	)
);

$wp_customize->add_control(
	'blog_center_breaking_news_category',
	array(
		'label'           => esc_html__( 'Category', 'blog-center' ),
		'section'         => 'blog_center_breaking_news_section',
		'type'            => 'select',
		'choices'         => blog_center_get_post_cat_choices(),
		'active_callback' => 'blog_center_breaking_news_section_content_type_category_enabled',
	)
);

/*========================Active Callback==============================*/
function blog_center_if_breaking_news_enabled( $control ) {
	return $control->manager->get_setting( 'blog_center_breaking_news_section_enable' )->value();
}
function blog_center_breaking_news_section_content_type_post_enabled( $control ) {
	$content_type = $control->manager->get_setting( 'blog_center_breaking_news_content_type' )->value();
	return blog_center_if_breaking_news_enabled( $control ) && ( 'post' === $content_type );
}
function blog_center_breaking_news_section_content_type_category_enabled( $control ) {
	$content_type = $control->manager->get_setting( 'blog_center_breaking_news_content_type' )->value();
	return blog_center_if_breaking_news_enabled( $control ) && ( 'category' === $content_type );
}

/*========================Partial Refresh==============================*/
if ( ! function_exists( 'blog_center_breaking_news_title_text_partial' ) ) :
	// Title.
	function blog_center_breaking_news_title_text_partial() {
		return esc_html( get_theme_mod( 'blog_center_breaking_news_title' ) );
	}
endif;
