<?php
/**
 * Adore Themes Customizer
 *
 * @package Blog Center
 *
 * Instagram Section
 */

$wp_customize->add_section(
	'blog_center_instagram_section',
	array(
		'title' => esc_html__( 'Instagram Section', 'blog-center' ),
		'panel' => 'blog_center_frontpage_panel',
	)
);

// Instagram Section section enable settings.
$wp_customize->add_setting(
	'blog_center_instagram_section_enable',
	array(
		'default'           => false,
		'sanitize_callback' => 'blog_center_sanitize_checkbox',
	)
);

$wp_customize->add_control(
	new Blog_Center_Toggle_Checkbox_Custom_control(
		$wp_customize,
		'blog_center_instagram_section_enable',
		array(
			'label'    => esc_html__( 'Enable Instagram Section', 'blog-center' ),
			'type'     => 'checkbox',
			'settings' => 'blog_center_instagram_section_enable',
			'section'  => 'blog_center_instagram_section',
		)
	)
);

// Instagram Instagram Title settings.
$wp_customize->add_setting(
	'blog_center_instagram_title',
	array(
		'default'           => __( 'Instagram', 'blog-center' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'blog_center_instagram_title',
	array(
		'label'           => esc_html__( 'Instagram Label', 'blog-center' ),
		'section'         => 'blog_center_instagram_section',
		'active_callback' => 'blog_center_if_instagram_enabled',
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'blog_center_instagram_title',
		array(
			'selector'            => '.instagram-section h3.section-title',
			'settings'            => 'blog_center_instagram_title',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'blog_center_instagram_title_text_partial',
		)
	);
}

// Instagram Section - Image Url.
$wp_customize->add_setting(
	'blog_center_instagram_link',
	array(
		'default'           => '#',
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control(
	'blog_center_instagram_link',
	array(
		'label'           => esc_html__( 'Instagram Link', 'blog-center' ),
		'section'         => 'blog_center_instagram_section',
		'settings'        => 'blog_center_instagram_link',
		'type'            => 'url',
		'active_callback' => 'blog_center_if_instagram_enabled',
	)
);

for ( $i = 1; $i <= 4; $i++ ) {

	// Instagram image.
	$wp_customize->add_setting(
		'blog_center_instagram_image_' . $i,
		array(
			'default'           => '',
			'sanitize_callback' => 'blog_center_sanitize_image',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'blog_center_instagram_image_' . $i,
			array(
				'label'           => sprintf( esc_html__( 'Image %d', 'blog-center' ), $i ),
				'section'         => 'blog_center_instagram_section',
				'settings'        => 'blog_center_instagram_image_' . $i,
				'active_callback' => 'blog_center_if_instagram_enabled',
			)
		)
	);

}

/*========================Active Callback==============================*/
function blog_center_if_instagram_enabled( $control ) {
	return $control->manager->get_setting( 'blog_center_instagram_section_enable' )->value();
}

/*========================Partial Refresh==============================*/
if ( ! function_exists( 'blog_center_instagram_title_text_partial' ) ) :
	// Title.
	function blog_center_instagram_title_text_partial() {
		return esc_html( get_theme_mod( 'blog_center_instagram_title' ) );
	}
endif;
