<?php
/**
 * Blog / Archive Options
 */

$wp_customize->add_section(
	'blog_center_archive_page_options',
	array(
		'title' => esc_html__( 'Blog / Archive Pages Options', 'blog-center' ),
		'panel' => 'blog_center_theme_options_panel',
	)
);

// Excerpt - Excerpt Length.
$wp_customize->add_setting(
	'blog_center_excerpt_length',
	array(
		'default'           => 35,
		'sanitize_callback' => 'blog_center_sanitize_number_range',
	)
);

$wp_customize->add_control(
	'blog_center_excerpt_length',
	array(
		'label'       => esc_html__( 'Excerpt Length (no. of words)', 'blog-center' ),
		'section'     => 'blog_center_archive_page_options',
		'settings'    => 'blog_center_excerpt_length',
		'type'        => 'number',
		'input_attrs' => array(
			'min'  => 5,
			'max'  => 200,
			'step' => 1,
		),
	)
);

// Grid Column layout options.
$wp_customize->add_setting(
	'blog_center_archive_grid_column_layout',
	array(
		'default'           => 'grid-column-4',
		'sanitize_callback' => 'blog_center_sanitize_select',
	)
);

$wp_customize->add_control(
	'blog_center_archive_grid_column_layout',
	array(
		'label'           => esc_html__( 'Grid Column Layout', 'blog-center' ),
		'section'         => 'blog_center_archive_page_options',
		'type'            => 'select',
		'choices'         => array(
			'grid-column-3' => __( 'Column 3', 'blog-center' ),
			'grid-column-4' => __( 'Column 4', 'blog-center' ),
		),
	)
);

// Enable archive page category setting.
$wp_customize->add_setting(
	'blog_center_enable_archive_category',
	array(
		'default'           => true,
		'sanitize_callback' => 'blog_center_sanitize_checkbox',
	)
);

$wp_customize->add_control(
	new Blog_Center_Toggle_Checkbox_Custom_control(
		$wp_customize,
		'blog_center_enable_archive_category',
		array(
			'label'    => esc_html__( 'Enable Category', 'blog-center' ),
			'settings' => 'blog_center_enable_archive_category',
			'section'  => 'blog_center_archive_page_options',
			'type'     => 'checkbox',
		)
	)
);

// Enable archive page author setting.
$wp_customize->add_setting(
	'blog_center_enable_archive_author',
	array(
		'default'           => true,
		'sanitize_callback' => 'blog_center_sanitize_checkbox',
	)
);

$wp_customize->add_control(
	new Blog_Center_Toggle_Checkbox_Custom_control(
		$wp_customize,
		'blog_center_enable_archive_author',
		array(
			'label'    => esc_html__( 'Enable Author', 'blog-center' ),
			'settings' => 'blog_center_enable_archive_author',
			'section'  => 'blog_center_archive_page_options',
			'type'     => 'checkbox',
		)
	)
);

// Enable archive page date setting.
$wp_customize->add_setting(
	'blog_center_enable_archive_date',
	array(
		'default'           => true,
		'sanitize_callback' => 'blog_center_sanitize_checkbox',
	)
);

$wp_customize->add_control(
	new Blog_Center_Toggle_Checkbox_Custom_control(
		$wp_customize,
		'blog_center_enable_archive_date',
		array(
			'label'    => esc_html__( 'Enable Date', 'blog-center' ),
			'settings' => 'blog_center_enable_archive_date',
			'section'  => 'blog_center_archive_page_options',
			'type'     => 'checkbox',
		)
	)
);
